@@ -266,8 +266,8 @@ class AMPAPIAsync():
         data = {"InstanceId": InstanceId, "PortMappings": PortMappings, }
         return await self.APICallAsync(endpoint="/ADSModule/SetInstanceNetworkInfo", data=data)
 
-    async def ADSModule_ApplyInstanceConfigurationAsync(self, InstanceID, Flags):
-        data = {"InstanceID": InstanceID, "Flags": Flags, }
+    async def ADSModule_ApplyInstanceConfigurationAsync(self, InstanceID, Args, RebuildConfiguration):
+        data = {"InstanceID": InstanceID, "Args": Args, "RebuildConfiguration": RebuildConfiguration, }
         return await self.APICallAsync(endpoint="/ADSModule/ApplyInstanceConfiguration", data=data)
 
     async def ADSModule_CreateLocalInstanceAsync(self, Instance, PostCreate):
@@ -558,6 +558,10 @@ class AMPAPIAsync():
         data = {"Id": Id, "months": months, "days": days, "hours": hours, "minutes": minutes, "daysOfMonth": daysOfMonth, "description": description, }
         return await self.APICallAsync(endpoint="/Core/EditIntervalTrigger", data=data)
 
+    async def Core_SetTriggerEnabledAsync(self, Id, Enabled):
+        data = {"Id": Id, "Enabled": Enabled, }
+        return await self.APICallAsync(endpoint="/Core/SetTriggerEnabled", data=data)
+
     async def Core_AddTaskAsync(self, TriggerID, MethodID, ParameterMapping):
         data = {"TriggerID": TriggerID, "MethodID": MethodID, "ParameterMapping": ParameterMapping, }
         return await self.APICallAsync(endpoint="/Core/AddTask", data=data)
@@ -698,6 +702,10 @@ class AMPAPIAsync():
         data = {"TaskId": TaskId, }
         return await self.APICallAsync(endpoint="/Core/DismissTask", data=data)
 
+    async def Core_DismissAllTasksAsync(self, ):
+        data = {}
+        return await self.APICallAsync(endpoint="/Core/DismissAllTasks", data=data)
+
     async def Core_GetUserInfoAsync(self, UID):
         data = {"UID": UID, }
         return await self.APICallAsync(endpoint="/Core/GetUserInfo", data=data)
